@@ -186,9 +186,9 @@ pub fn crawl_trade(
         "binance" => crawlers::binance::crawl_trade(market_type, symbols, tx, duration),
         "bitmex" => crawlers::bitmex::crawl_trade(market_type, symbols, tx, duration),
         "deribit" => crawlers::deribit::crawl_trade(market_type, symbols, tx, duration),
-        "okex" => crawlers::okex::crawl_trade(market_type, symbols, tx, duration),
+        // "okx" => crawlers::okx::crawl_trade(market_type, symbols, tx, duration),
         "bitfinex" | "bitget" | "bithumb" | "bitstamp" | "bitz" | "bybit" | "coinbase_pro"
-        | "dydx" | "ftx" | "gate" | "huobi" | "kraken" | "kucoin" | "mxc" | "zbg" => {
+        | "dydx" | "ftx" | "gate" | "huobi" | "kraken" | "kucoin" | "mxc" | "okx" | "zbg" => {
             crawlers::crawl_event(
                 exchange,
                 MessageType::Trade,
@@ -215,7 +215,7 @@ pub fn crawl_l2_event(
         "bitmex" => crawlers::bitmex::crawl_l2_event(market_type, symbols, tx, duration),
         "huobi" => crawlers::huobi::crawl_l2_event(market_type, symbols, tx, duration),
         "bitfinex" | "bitget" | "bithumb" | "bitstamp" | "bitz" | "bybit" | "coinbase_pro"
-        | "deribit" | "dydx" | "ftx" | "gate" | "kraken" | "kucoin" | "mxc" | "okex" | "zbg" => {
+        | "deribit" | "dydx" | "ftx" | "gate" | "kraken" | "kucoin" | "mxc" | "okx" | "zbg" => {
             crawlers::crawl_event(
                 exchange,
                 MessageType::L2Event,
@@ -286,7 +286,7 @@ pub fn crawl_bbo(
         "binance" => crawlers::binance::crawl_bbo(market_type, symbols, tx, duration),
         "bitmex" => crawlers::bitmex::crawl_bbo(market_type, symbols, tx, duration),
         "kucoin" => crawlers::kucoin::crawl_bbo(market_type, symbols, tx, duration),
-        "bitfinex" | "deribit" | "ftx" | "gate" | "huobi" | "kraken" | "okex" => {
+        "bitfinex" | "deribit" | "ftx" | "gate" | "huobi" | "kraken" | "okx" => {
             crawlers::crawl_event(
                 exchange,
                 MessageType::BBO,
@@ -311,7 +311,7 @@ pub fn crawl_l2_topk(
     match exchange {
         "binance" => crawlers::binance::crawl_l2_topk(market_type, symbols, tx, duration),
         "bitmex" => crawlers::bitmex::crawl_l2_topk(market_type, symbols, tx, duration),
-        "bitget" | "bybit" | "bitstamp" | "deribit" | "huobi" | "kucoin" | "mxc" | "okex" => {
+        "bitget" | "bybit" | "bitstamp" | "deribit" | "huobi" | "kucoin" | "mxc" | "okx" => {
             crawlers::crawl_event(
                 exchange,
                 MessageType::L2TopK,
@@ -360,7 +360,7 @@ pub fn crawl_ticker(
     match exchange {
         "binance" => crawlers::binance::crawl_ticker(market_type, symbols, tx, duration),
         "bitfinex" | "bitget" | "bithumb" | "bitz" | "bybit" | "coinbase_pro" | "deribit"
-        | "gate" | "huobi" | "kraken" | "kucoin" | "mxc" | "okex" | "zbg" => crawlers::crawl_event(
+        | "gate" | "huobi" | "kraken" | "kucoin" | "mxc" | "okx" | "zbg" => crawlers::crawl_event(
             exchange,
             MessageType::Ticker,
             market_type,
@@ -385,7 +385,7 @@ pub fn crawl_funding_rate(
         "bitget" => crawlers::bitget::crawl_funding_rate,
         "bitmex" => crawlers::bitmex::crawl_funding_rate,
         "huobi" => crawlers::huobi::crawl_funding_rate,
-        "okex" => crawlers::okex::crawl_funding_rate,
+        "okx" => crawlers::okx::crawl_funding_rate,
         _ => panic!("{} does NOT have perpetual swap market", exchange),
     };
     func(market_type, symbols, tx, duration);
@@ -410,7 +410,7 @@ pub fn crawl_candlestick(
             crawlers::bitmex::crawl_candlestick(market_type, symbol_interval_list, tx, duration)
         }
         "bitfinex" | "bitget" | "bitz" | "bybit" | "deribit" | "gate" | "huobi" | "kraken"
-        | "kucoin" | "mxc" | "okex" | "zbg" => crawlers::crawl_candlestick_ext(
+        | "kucoin" | "mxc" | "okx" | "zbg" => crawlers::crawl_candlestick_ext(
             exchange,
             market_type,
             symbol_interval_list,
