@@ -13,7 +13,7 @@ const EXCHANGE_NAME: &str = "kucoin";
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMZ21"; "inconclusive")]
+#[test_case(MarketType::InverseFuture, "XBTMH22"; "inconclusive")]
 fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_trade,
@@ -27,7 +27,7 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMZ21")]
+#[test_case(MarketType::InverseFuture, "XBTMH22")]
 fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_event,
@@ -41,7 +41,7 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMZ21")]
+#[test_case(MarketType::InverseFuture, "XBTMH22")]
 fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_bbo,
@@ -55,7 +55,7 @@ fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMZ21")]
+#[test_case(MarketType::InverseFuture, "XBTMH22")]
 fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_topk,
@@ -69,7 +69,7 @@ fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMZ21")]
+#[test_case(MarketType::InverseFuture, "XBTMH22")]
 fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l3_event,
@@ -83,7 +83,7 @@ fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMZ21")]
+#[test_case(MarketType::InverseFuture, "XBTMH22")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_snapshot,
@@ -110,7 +110,7 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
 #[test_case(MarketType::Spot, "BTC-USDT"; "inconclusive")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMZ21")]
+#[test_case(MarketType::InverseFuture, "XBTMH22")]
 fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l3_snapshot,
@@ -124,7 +124,7 @@ fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMZ21")]
+#[test_case(MarketType::InverseFuture, "XBTMH22")]
 fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_ticker,
